import sqlite3
import xml.sax 

conn = sqlite3.connect('emp.db')
conn.row_factory = sqlite3.Row

c = conn.cursor()
c.execute('''DROP TABLE IF EXISTS DEPARTEMENT''')
c.execute('''CREATE TABLE DEPARTEMENT (
                ID    INTEGER PRIMARY KEY AUTOINCREMENT,
                NOM  TEXT,
                VILLE TEXT
             )''')
c.execute('''DROP TABLE IF EXISTS EMPLOYE''')
c.execute('''CREATE TABLE IF NOT EXISTS EMPLOYE (
                ID       INTEGER PRIMARY KEY AUTOINCREMENT, 
                NOM      TEXT NOT NULL,
                PRENOM   TEXT NOY NULL,
                SALAIRE  FLOAT NOT NULL,
                TAUX     FLOAT,
                ID_DEPARTEMENT INT REFERENCES DEPARTEMENT(ID)
             )''');



class TravahoHandler(xml.sax.ContentHandler):
    def __init__(self):
        self.id_employe = None
        self.ville_departement = None
        self.nom_departement = None
        self.id_departement = None
        self.inside_departement = False

    def startDocument(self):
        pass

    def startElement(self, xml_name, xml_attrs):
        if xml_name == 'travail':
            pass
        elif xml_name == 'employe':
            nom = xml_attrs['nom'].strip()
            prenom = xml_attrs['prenom'].strip()
            salaire = float(xml_attrs['salaire'].strip())
            if 'taux' in xml_attrs:
                taux = float(xml_attrs['taux'].strip())
            else:
                taux = None

            c.execute('INSERT INTO EMPLOYE(NOM,PRENOM,SALAIRE,TAUX) VALUES (?,?,?,?)',
                      (nom,prenom,salaire,taux));

            self.id_employe = c.lastrowid

        elif xml_name == 'departement':
            self.ville_departement = xml_attrs['ville']
            self.nom_departement = ""
            self.inside_departement = True
        else:
            pass

    def characters(self, text):
        if self.inside_departement:
            self.nom_departement += text
 
    def endElement(self, xml_name):
        if xml_name == 'departement':
            c.execute('SELECT ID FROM DEPARTEMENT WHERE NOM = ? AND VILLE = ?',
                      (self.nom_departement,self.ville_departement));
            d = c.fetchone()
            if d:
                self.id_departement = d['ID']
            else: # the department has not been yet entered in the database

                c.execute('INSERT INTO DEPARTEMENT(NOM,VILLE) VALUES (?,?)',
                          (self.nom_departement,self.ville_departement))
                self.id_departement = c.lastrowid

            self.inside_departement = False
        elif xml_name == 'employe':
            c.execute('UPDATE EMPLOYE SET ID_DEPARTEMENT = ? WHERE ID = ?',
                      (self.id_departement,self.id_employe))

    def endDocument(self):
        conn.commit()
            


if __name__ == '__main__':
    parser = xml.sax.make_parser()
    parser.setContentHandler(TravahoHandler())
    parser.parse(open('rh.xml','r'))
    conn.close()

